@@ -4,12 +4,12 @@ test_that("can read new data", {
   path <- tempfile()
 
   x <- 1:100
-  write_feather(dplyr::data_frame(x = x), path)
+  write_feather(tibble::tibble(x = x), path)
   on.exit(file.remove(path))
   res <- read_feather(path)
 
   y <- x[1:(length(x)/2)]
-  write_feather(dplyr::data_frame(y = y), path)
+  write_feather(tibble::tibble(y = y), path)
   resy <- read_feather(path)
   expect_identical(resy$y, y)
 })
